{
  config,
  lib,
  pkgs,
  inputs,
  ...
}: {
  imports = [
    inputs.nix-index-database.hmModules.nix-index
  ];

  home.packages = [
    pkgs.file
    pkgs.pciutils # lspci
    pkgs.usbutils # lsusb

    pkgs.bottom
    pkgs.htop
    pkgs.lsof
    pkgs.lm_sensors
    pkgs.amdgpu_top
    #pkgs.rocmPackages.rocm-smi
    pkgs.ryzenadj
    pkgs.powertop
    pkgs.procs

    pkgs.sshfs

    pkgs.fd
    pkgs.libqalculate
    # pkgs.havn # port scanner
    pkgs.gdu # count code
    pkgs.tokei # count code
    pkgs.ov # pager
    pkgs.zoxide # cd
    pkgs.dua

    pkgs.unzip
    pkgs.unrar-wrapper
    pkgs.p7zip
    pkgs.atool

    pkgs.fastfetch
    pkgs.hyfetch

    pkgs.helix # `hx` editor
    pkgs.jujutsu # `jj` vcs
  ];

  programs.atuin = {
    enable = true;
    settings.update_check = false;
    settings.enter_accept = true;
  };

  programs.autojump.enable = true;

  programs.bat.enable = true;

  # maybe move boxxy here?

  programs.broot.enable = true;

  programs.direnv = {
    enable = true;
    nix-direnv.enable = true;
    # Externally located cache
    stdlib = ''
      declare -A direnv_layout_dirs
      direnv_layout_dir() {
          local hash path
          echo "''${direnv_layout_dirs[$PWD]:=$(
              hash="$(sha1sum - <<< "$PWD" | head -c40)"
              path="''${PWD//[^a-zA-Z0-9]/-}"
              echo "${config.xdg.cacheHome}/direnv/layouts/''${hash}''${path}"
          )}"
      }
    '';
  };

  programs.eza = {
    enable = true;
    git = true;
    icons = "auto";
  };

  programs.fish = {
    enable = true;
    functions = {
      #__fish_command_not_found_handler = {
      #  body = "__fish_default_command_not_found_handler $argv[1]";
      #  onEvent = "fish_command_not_found";
      #};
    };
    shellInit = "set fish_greeting";
  };

  # maybe move git here?

  programs.jq.enable = true;

  programs.nix-index.enable = true;
  programs.nix-index-database.comma.enable = true;

  programs.ripgrep.enable = true;

  programs.skim.enable = true;

  programs.starship = {
    enable = true;
    enableTransience = true;
    settings.nix_shell.format = "❄️️";
  };

  # programs.yazi = {
  #   enable = true;
  #   settings.preview.cache_dir = "${config.xdg.cacheHome}/thumbnails/yazi";
  # };
}
